@@ -1,10 +1,13 @@
-from cprint.main import cp, cf
+import cprint
+import cprint.main
 from cprint.tools import demo as _demo
 from cprint.tools import demoid as _demoid
 from cprint.tools import getshow_config as _showconfig
 
+cprint.custom_style = {}
+
 _cpshow = lambda : _showconfig(2)
 _cpshoww = lambda : _showconfig(3)
 
-config = tools = main = None
-del config, tools, main
\ No newline at end of file
+config = cprint = main = tools = None
+del config, cprint, main, tools
\ No newline at end of file
