@@ -1,4 +1,5 @@
 import re
+import cprint
 from cprint.tools import getshow_config
 from cprint.config import CONTANT_DICT
 from forbiddenfruit import curse
@@ -45,4 +46,30 @@ def cf(text: str) -> str:
 def cformat(self, *args, **kwargs):
     return cf(self).format(*args, **kwargs)
 
-curse(str, "cformat", cformat)
\ No newline at end of file
+curse(str, "cformat", cformat)
+
+def idf(text: str) -> str:
+    """
+    Colorful Format
+    文档:
+        使用style_id格式化字符串
+    参数:
+        text: str
+            需要格式化的字符串
+    返回:
+        返回格式化好的字符串
+    """
+    def pr_march(match):
+
+        replace_text, style_id = match.groups()
+        return match.group().replace(replace_text, STYLE_CONFIG[cprint.custom_style.get(int(style_id), int(style_id))]) + "\033[0;0m"
+
+    for mark, mark_fun in CONTANT_DICT.items():
+        text = text.replace(mark, mark_fun())
+
+    return re.sub(PATTERN, pr_march, text)
+
+def iformat(self, *args, **kwargs):
+    return idf(self).format(*args, **kwargs)
+
+curse(str, "iformat", iformat)
\ No newline at end of file
